import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import {
  scaleLinear,
  extent,
  timeFormat,
  histogram as bin,
  timeMonths,
  sum,
  max,
} from 'd3';

import { Marks } from './Marks';

const margin = { top: 0, right: 30, bottom: 25, left: 60 };
const xAxisLabelOffset = 5;
const yAxisLabelOffset = 40;

export const DateHistogram = ({ width, height, data }) => {
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const xValue = (d) => d['Reported Date'];
  const xAxisLabel = 'Time';

  const yValue = (d) => d['Total Dead and Missing'];
  const yAxisLabel = 'Total Dead and Missing';

  const xAxisTickFormat = timeFormat('%m/%d/%Y');

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const [start, stop] = xScale.domain();

  const binnedData = bin()
    .value(xValue)
    .domain(xScale.domain())
    .thresholds(timeMonths(start, stop))(data)
    .map((a) => ({ x0: a.x0, x1: a.x1, y: sum(a, yValue) }));

  const yScale = scaleLinear()
    .domain([0, max(binnedData, (d) => d.y)])
    .range([innerHeight, 0])
    .nice();

  return (
    <>
      <rect width={width} height={height} fill="#fff" />
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={xAxisLabelOffset}
        />
        <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={10} />
        <Marks
          data={binnedData}
          xScale={xScale}
          yScale={yScale}
          innerHeight={innerHeight}
        />
      </g>
    </>
  );
};
